@@ -1,24 +1,22 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import PoolMeta, Pool
-from trytond.pyson import Eval
-
+from trytond.modules.currency.fields import Monetary
 from trytond.modules.product import price_digits, round_price
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
 
 
 class Move(metaclass=PoolMeta):
     __name__ = 'stock.move'
 
-    secondary_quantity = fields.Function(
-        fields.Float("Secondary Quantity",
-            digits=(16, Eval('secondary_unit_digits', 2)),
+    secondary_quantity = fields.Function(fields.Float(
+            "Secondary Quantity", digits='secondary_unit',
             states={
                 'invisible': ~Eval('secondary_unit'),
                 'readonly': Eval('state').in_(
                     ['cancelled', 'assigned', 'done']),
-                },
-            depends=['secondary_unit_digits', 'secondary_unit', 'state']),
+                }),
         'on_change_with_secondary_quantity', setter='set_secondary')
     secondary_unit = fields.Many2One(
         'product.uom', "Secondary Unit", ondelete='RESTRICT',
@@ -28,73 +26,69 @@ class Move(metaclass=PoolMeta):
         states={
             'invisible': ~Eval('product_secondary_uom_category'),
             'readonly': Eval('state').in_(['cancelled', 'assigned', 'done']),
-            },
-        depends=['product_secondary_uom_category', 'state'])
+            })
     secondary_unit_price = fields.Function(
-        fields.Numeric(
-            "Secondary Unit Price", digits=price_digits,
+        Monetary(
+            "Secondary Unit Price", currency='currency', digits=price_digits,
             states={
                 'invisible': (~Eval('unit_price_required')
                     | ~Eval('secondary_unit')),
                 'readonly': Eval('state') != 'draft',
-                },
-            depends=['unit_price_required', 'secondary_unit', 'state']),
+                }),
         'on_change_with_secondary_unit_price', setter='set_secondary')
 
-    secondary_unit_digits = fields.Function(
-        fields.Integer("Secondary Unit Digits"),
-        'on_change_with_secondary_unit_digits')
     product_secondary_uom_category = fields.Function(
         fields.Many2One(
-            'product.uom.category', "Product Secondary UOM Category"),
+            'product.uom.category', "Product Secondary UoM Category",
+            help="The category of secondary Unit of Measure for the product."),
         'get_product_secondary_uom_category')
 
-    @fields.depends('quantity', 'uom', 'secondary_unit', 'origin')
+    @fields.depends('quantity', 'unit', 'secondary_unit', 'origin')
     def on_change_with_secondary_quantity(self, name=None):
         pool = Pool()
         Uom = pool.get('product.uom')
-        if (self.quantity and self.uom and self.secondary_unit
+        if (self.quantity and self.unit and self.secondary_unit
                 and (self.secondary_uom_factor or self.secondary_uom_rate)):
             return Uom.compute_qty(
-                self.uom, self.quantity,
+                self.unit, self.quantity,
                 self.secondary_unit, round=True,
                 factor=self.secondary_uom_factor, rate=self.secondary_uom_rate)
         else:
             return None
 
-    @fields.depends('secondary_quantity', 'secondary_unit', 'uom', 'origin')
+    @fields.depends('secondary_quantity', 'secondary_unit', 'unit', 'origin')
     def on_change_secondary_quantity(self):
         pool = Pool()
         Uom = pool.get('product.uom')
-        if (self.secondary_quantity and self.secondary_unit and self.uom
+        if (self.secondary_quantity and self.secondary_unit and self.unit
                 and (self.secondary_uom_factor or self.secondary_uom_rate)):
             self.quantity = Uom.compute_qty(
                 self.secondary_unit, self.secondary_quantity,
-                self.uom, round=True,
+                self.unit, round=True,
                 factor=self.secondary_uom_rate, rate=self.secondary_uom_factor)
 
-    @fields.depends('unit_price', 'uom', 'secondary_unit', 'origin')
+    @fields.depends('unit_price', 'unit', 'secondary_unit', 'origin')
     def on_change_with_secondary_unit_price(self, name=None):
         pool = Pool()
         Uom = pool.get('product.uom')
-        if (self.unit_price and self.uom and self.secondary_unit
+        if (self.unit_price and self.unit and self.secondary_unit
                 and (self.secondary_uom_factor or self.secondary_uom_rate)):
             unit_price = Uom.compute_price(
-                self.uom, self.unit_price, self.secondary_unit,
+                self.unit, self.unit_price, self.secondary_unit,
                 factor=self.secondary_uom_factor, rate=self.secondary_uom_rate
                 )
             return round_price(unit_price)
         else:
             return None
 
-    @fields.depends('secondary_unit_price', 'secondary_unit', 'uom', 'origin')
+    @fields.depends('secondary_unit_price', 'secondary_unit', 'unit', 'origin')
     def on_change_secondary_unit_price(self, name=None):
         pool = Pool()
         Uom = pool.get('product.uom')
-        if (self.secondary_unit_price and self.secondary_unit and self.uom
+        if (self.secondary_unit_price and self.secondary_unit and self.unit
                 and (self.secondary_uom_factor or self.secondary_uom_rate)):
             self.unit_price = Uom.compute_price(
-                self.secondary_unit, self.secondary_unit_price, self.uom,
+                self.secondary_unit, self.secondary_unit_price, self.unit,
                 factor=self.secondary_uom_rate, rate=self.secondary_uom_factor)
             self.unit_price = round_price(self.unit_price)
 
@@ -104,11 +98,6 @@ class Move(metaclass=PoolMeta):
         self.on_change_secondary_quantity()
         self.on_change_secondary_unit_price()
 
-    @fields.depends('secondary_unit')
-    def on_change_with_secondary_unit_digits(self, name=None):
-        if self.secondary_unit:
-            return self.secondary_unit.digits
-
     def get_product_secondary_uom_category(self, name):
         category = None
         if self.secondary_unit:
